@@ -2,7 +2,7 @@
 
 from .version import clspy_Version
 
-from .config import Config, ConfigType
+from .config import Config, ConfigType, ConfigUnique
 
 from .singleton import clspy_singleton
 from .singleton import SingletonClass
@@ -12,9 +12,13 @@ from .crypto import Md5
 
 from .log import Logger
 
+from .db import Sql
+
+from .utils import *
+
 __all__ = [
-    'Config', 'ConfigType', 'clspy_singleton', 'SingletonClass',
-    'SingletonMetaclass', 'Md5', 'Logger'
+    'Config', 'ConfigType', 'ConfigUnique', 'clspy_singleton',
+    'SingletonClass', 'SingletonMetaclass', 'Md5', 'Logger', 'Sql'
 ]
 
 __version__ = clspy_Version
